### Name: rtreeshape
### Title: Generate a list of random binary trees according to a given
###   model
### Aliases: rtreeshape rbiased rpda ryule
### Keywords: datagen

### ** Examples


## Summary of a PDA tree with 100 tips:
summary(rpda(100))
## Summary of a Yule tree with 100 tips:
summary(ryule(100))
  
## Generate trees with different sizes
trees=rtreeshape(n=2, tip.number=c(10,20), model="yule")
length(trees)
plot(trees[[1]])
plot(trees[[4]])
  
## Histogram of Colless' indices for a list of 1000 PDA trees with 60 tips
hist(sapply(rtreeshape(1000,60,model="pda"),FUN=colless,norm="pda"),freq=FALSE)

## Histogram of shape statistics for a list of 1000 Yule trees with 100 tips 
##      (takes some time to compute) 
main="Histogram of shape statistics for a list of 1000 Yule trees"
hist(sapply(rtreeshape(1000,100,model="yule"),FUN=shape.statistic,norm="yule"),
      freq=FALSE, main=main)
## It should be a gaussian with mean 0 and standard deviation 1.
x<-seq(-4,4,by=0.01)
lines(x,dnorm(x))       

## Building a tree using Markov splitting model
Q <- function(n,i) {
      if (i==1) {return(1)}
      else {return(0)}
}
tree=rtreeshape(n=1, tip.number=10, Q=Q)
plot(tree)



